Index: /trunk/SophyaPI/PI/piapplgen.cc
===================================================================
--- /trunk/SophyaPI/PI/piapplgen.cc	(revision 3561)
+++ /trunk/SophyaPI/PI/piapplgen.cc	(revision 3562)
@@ -54,4 +54,7 @@
 #include "sopnamsp.h"
 #include "piapplgen.h"
+#include <stdlib.h>
+#include <iostream>
+#include "pidrawer.h"
 
 // Variable qui contient le pointeur de l'application courante
@@ -62,5 +65,17 @@
 :topcont(NULL), menubar(NULL), mState(0)
 {
-curapp = this;   
+  curapp = this;   
+// Si la variable d'environnement PIDEFAFSZFRAC est definie, on modifie 
+// la taille par defaut de AutoFontSizeFrac
+  char *envafsz = getenv("PIDEFAFSZFRAC");
+  if (envafsz) {
+    double fsfr = atof(envafsz);
+    if ((fsfr>0.)&&(fsfr<1.)) {
+      PIDrawer::SetGlDefAutoFontSizeFrac(fsfr);
+      cout << " PIApplicationGen()/Info: getenv(PIDEFAFSZFRAC)=" << envafsz << endl;
+      cout << "  ... Set Global Default PIDrawer AutoFontSizeFrac to " 
+           << PIDrawer::GetGlDefAutoFontSizeFrac() << endl;
+      }
+  }
 }
 
Index: /trunk/SophyaPI/PI/piaxes.cc
===================================================================
--- /trunk/SophyaPI/PI/piaxes.cc	(revision 3561)
+++ /trunk/SophyaPI/PI/piaxes.cc	(revision 3562)
@@ -11,4 +11,5 @@
 #include <math.h>
 #include "piaxes.h"
+#include "pidrawer.h"
 
 //++
@@ -41,5 +42,5 @@
 {
   ConfigureTicks();
-  ConfigureAutoFontSize();
+  ConfigureAutoFontSize(true, PIDrawer::GetGlDefAutoFontSizeFrac());
   ConfigureAxesCenter();
   setupDone = false;
@@ -322,6 +323,6 @@
 //	(X/Y max-min). Les paramètres ne sont pas changés si des valeurs
 //	négatives ou nulles sont spécifiées.
-// void ConfigureAutoFontSize(double fszf=0.0125)
-//	Configuration de la taille de fonte, en mode AutoFontSize.
+// void ConfigureAutoFontSize(bool afsz=true, double fszf=0.04)
+//	Configuration de la taille de fonte, en mode AutoFontSize ou FixedFontSize.
 //	La taille est exprimée en fraction de la taille totale YMax-Min
 // void  ConfigureAxesCenter(bool fset,double x0,double y0)
Index: /trunk/SophyaPI/PI/piaxes.h
===================================================================
--- /trunk/SophyaPI/PI/piaxes.h	(revision 3561)
+++ /trunk/SophyaPI/PI/piaxes.h	(revision 3562)
@@ -60,5 +60,6 @@
   void  ConfigureTicks(int ntickx=10, int nticky=12, 
 		       double majtl=0.016, double mintl=0.01);
-  void  ConfigureAutoFontSize(bool afsz=true, double fszf=0.06);
+  //  Choix de taille automatique de fontes 
+  void  ConfigureAutoFontSize(bool afsz=true, double fszf=0.04);
   void  ConfigureAxesCenter(bool fset=false,double x0=0.,double y0=0.);
 
Index: /trunk/SophyaPI/PI/pidrawer.h
===================================================================
--- /trunk/SophyaPI/PI/pidrawer.h	(revision 3561)
+++ /trunk/SophyaPI/PI/pidrawer.h	(revision 3562)
@@ -31,7 +31,11 @@
   virtual void       SetAxesFlags(unsigned int flags=kAxesNone);
 
-//  Choix automatique ou pas de taille de fonte
-  inline void        ConfigureAutoFontSize(bool afsz=true, double fszf=0.06)
+//---- Choix automatique ou pas de taille de fonte
+  inline void        ConfigureAutoFontSize(bool afsz=true, double fszf=0.04)
     { mAFSz = afsz;  if (fszf>1e-5)  mFontSzF = fszf; }
+//  Valeur par defaut global pour le AutoFontSizeFrac, utilise dans les constructeurs de PIDrawer
+  static  void       SetGlDefAutoFontSizeFrac(double fszf=0.04);
+//  Retourne la valeur globale par defaut de AutoFontSizeFrac
+  static  double     GetGlDefAutoFontSizeFrac();
 
   virtual void       DrawAxes(PIGraphicUC* g);
@@ -135,4 +139,5 @@
   bool mAFSz;  // true -> Choix automatique de taille de font en fraction (ymax-ymin)
   double mFontSzF;   // TailleFonteAuto = mFontSzF*(ymax-ymin)
+  static double glDefAFSzFrac;   // Valeur globale par defaut pour mFontSzF, utilise ds le constructeur
 
   PIBaseWdgGen* mBWdg;

Index: /trunk/SophyaPI/PI/pidrawer.cc
===================================================================
--- /trunk/SophyaPI/PI/pidrawer.cc	(revision 3561)
+++ /trunk/SophyaPI/PI/pidrawer.cc	(revision 3562)
@@ -52,4 +52,15 @@
 //--
 
+// Valeur par defaut global pour TailleFonteAuto 
+double PIDrawer::glDefAFSzFrac = 0.04;
+void PIDrawer::SetGlDefAutoFontSizeFrac(double fszf)
+{
+  if (fszf>1.e-6)  glDefAFSzFrac = fszf;
+}
+double PIDrawer::GetGlDefAutoFontSizeFrac()
+{
+  return glDefAFSzFrac;
+}
+
 PIDrawer::PIDrawer()
 {
@@ -65,5 +76,5 @@
   limitsFixed = false;
   SetAxesFlags(kAxesNone);   // Pas de trace d'axes par defaut 
-  ConfigureAutoFontSize();
+  ConfigureAutoFontSize(true, glDefAFSzFrac);
 
   mDndfg = false;  // Pour controle de l'appel de Detach() si delete
@@ -143,12 +154,20 @@
 //|	kMajTicks , kMinTicks , kLabels , kGridOn
 //|	kAxesDflt , kAxesNone
-// void SetAxesAutoFontSize(bool fg=true)
-//	Si "fg==true", la taille de la fonte pour les labels d'axes (chiffres) est 
+// void ConfigureAutoFontSize(bool afsz=true, double fszf=0.05)
+//	Si "fg==true", la taille de la fonte par le drawer, est 
 //	choisie automatiquement, en s'adaptant à la taille de la zone de tracé - 
-//	sinon, taille de la fonte de l'objet PIDrawer.
+//	sinon, taille de la fonte de l'objet PIDrawer. Cette taille est donnée par
+//	FontSize=(YMax()-YMin())*(mFontSzF=fszf). "mFontSzF=fszf" n'est mis à jour
+//	que si fszf>0. Le décodage des attributs graphiques par DecodeOptionString() 
+//	("autofontsize=fszf" et "fixedfontsize")  permet de modifier ces attributs de 
+//	choix automtique de fonte. Utilisé en particulier par PIElDrawer pour 
+//	le tracé les labels d'axes (chiffres).
 // unsigned int GetAxesFlags()
 //	Renvoie les attributs de tracé d'axes  
 // bool  isAxesAutoFontSize()
 //	Renvoie la valeur du flag de choix automatique de taille de fonte pour axes.
 // void  DrawAxes(PIGraphicUC* g)
 //	Méthode de tracé des axes (le tracé est pris en charge par la classe *PIAxes*)
@@ -143,12 +154,20 @@
 // unsigned int GetAxesFlags()
 //	Renvoie les attributs de tracé d'axes  
-// bool  isAxesAutoFontSize()
-//	Renvoie la valeur du flag de choix automatique de taille de fonte pour axes.
+// bool  GetAutoFontSizeState() 
+//	Renvoie la valeur du flag de choix automatique de taille de fonte.
+// double  GetAutoFontSizeFraction()
+//	Renvoie la valeur de la fraction de taille ("mFontSzF) pour lee 
+//	choix automatique de taille de fonte.
 // void  DrawAxes(PIGraphicUC* g)
 //	Méthode de tracé des axes (le tracé est pris en charge par la classe *PIAxes*)